xgettext -c -ktr2i18n -o kipmsg.pot ../src/*.cpp
mv ja.po ja.po.orig
mv zh_CN.po zh_CN.po.orig
msgmerge ja.po.orig kipmsg.pot -o ja.po
msgmerge zh_CN.po.orig kipmsg.pot -o zh_CN.po
